@@ -10,9 +10,8 @@ console = Console(
     log_time=False,
     log_path=False,
     theme=custom_theme,
-    width=200,
-    color_system="256",
-    force_terminal=True,
+    color_system="auto",
+    record=True,
 )
 
 logging.basicConfig(
